<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ro_RO">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Există viaţă dincolo de browser!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Versiunea %1</translation>
    </message>
    <message>
        <source>This is a &quot;Technology Preview&quot; release, do not expect it to be perfect.</source>
        <translation type="obsolete">Această versiune este doar pentru o &quot;impresie tehnlogică&quot;, nu te aştepta să funcţioneze perfect.</translation>
    </message>
    <message>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>Raportează erori şi trimite ideile tale la %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 este un program gratuit, dar dezvoltarea acestuia necesită timp preţios.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate via PayPal&lt;/a&gt; to support the continued development of %2.</source>
        <translation type="obsolete">Te gog &lt;a href=&apos;%1&apos;&gt;donează o sumă modestă&lt;/a&gt; pentru a ajuta dezvoltarea %2.</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Iconul a fost conceput de %1.</translation>
    </message>
    <message>
        <source>Compact mode contributed by %1.</source>
        <translation>Modul compact a fost dezvoltat de %1.</translation>
    </message>
    <message>
        <source>HTTP proxy support contributed by %1.</source>
        <translation>Suportul pentru proxy-uri HTTP a fost dezvoltat de %1.</translation>
    </message>
    <message>
        <source>Windows version built by %1</source>
        <translation type="obsolete">Version Windows faite par %1</translation>
    </message>
    <message>
        <source>Translated by %1</source>
        <translation>Tradus de %1</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Oferit sub &lt;a href=&apos;%1&apos;&gt;Licenţa Publică Generală GNU&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>În&amp;chide</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Despre</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Tot ce ai vrut să ştii despre %1 dar n-ai vrut să îndrăzneşti a întreba</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Vă rugăm să &lt;a href=&apos;%1&apos;&gt;donaţi&lt;/a&gt; pentru a ajuta la continuarea dezvoltării %2.</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Şterge</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>KB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>minutes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <source>Searching...</source>
        <translation>Căutare...</translation>
    </message>
    <message>
        <source>Show %1 More</source>
        <translation>Afişează încă %1</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Nu sunt videoclipuri</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Nu mai sunt videoclipuri</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Eroare</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation type="obsolete">Îna&amp;poi</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation type="obsolete">Întoarcere</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Stop</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Opreşte redarea şi întoarce-te la căsuţa de căutare</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>O&amp;mite</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Treci la videoclipul următor</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pauză</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Pune redarea pe pauză</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>Ec&amp;ran complet</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Schimbă modul de vizualizare pe tot ecranul</translation>
    </message>
    <message>
        <source>&amp;Compact mode</source>
        <translation>Mod &amp;compact</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Ascunde lista de redare şi bara de unelte</translation>
    </message>
    <message>
        <source>&amp;YouTube</source>
        <translation type="obsolete">&amp;Youtube</translation>
    </message>
    <message>
        <source>Open the YouTube video page</source>
        <translation type="obsolete">Deschide pagina YouTube</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>Ş&amp;terge</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Şterge clipul selectat din lista de redare</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Mută în &amp;sus</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Mută în sus videoclipul selectat</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Mută în &amp;jos</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Mută în jos videoclipul selectat</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Ieşire</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>La revedere</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>Site &amp;Web</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 pe Web</translation>
    </message>
    <message>
        <source>&amp;Donate via PayPal</source>
        <translation type="obsolete">&amp;Donează prin PayPal</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Te rog să susţii dezvoltarea aplicaţiei %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Despre</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Informaţii despre %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Căutare</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Oprire sunet</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Listă de redare</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ajutor</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Apasă pe %1 pentru a da volumul mai tare sau pe %2 pentru a-l da mai încet</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Deschidere %1</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Eroare fatală : %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Eroare: %1</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Redare</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Rezumă redarea videoclipului</translation>
    </message>
    <message>
        <source>Exit &amp;Full Screen</source>
        <translation>Părăseşte modul &quot;Ec&amp;ran complet&quot;</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Timp rămas : %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Volum %1</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Sunetul este oprit</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Sunetul este pornit</translation>
    </message>
    <message>
        <source>High Definition video is enabled</source>
        <translation type="obsolete">Modul Înaltă Definiţie este activ</translation>
    </message>
    <message>
        <source>High Definition video is not enabled</source>
        <translation type="obsolete">Modul Înaltă Definiţie nu este activ</translation>
    </message>
    <message>
        <source>The current video is in High Definition</source>
        <translation type="obsolete">Videoclipul curent este în format Înaltă Definiţie</translation>
    </message>
    <message>
        <source>The current video is not in High Definition</source>
        <translation type="obsolete">Videoclipul curent nu este în format Înaltă Definiţie</translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation type="obsolete">Şterge &amp;căutările recente</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Aplicaţie</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Curăţă istoricul de căutări. Această acţiune nu poate fi anulată.</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>Intimitatea dumneavoastră este acum în siguranţă</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube page</source>
        <translation>Deschide pagina &amp;YouTube</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Deschide pagina de pe YouTube si pune pauză</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;link</source>
        <translation>Copiază &amp;link-ul de YouTube</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Copiază link-ul videoclipului curent în clipboard</translation>
    </message>
    <message>
        <source>Copy the video stream &amp;URL</source>
        <translation>Copiază adresa streamul&amp;ui</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Copiază adresa stream-ului în clipboard</translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation>&amp;Donează</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Rezoluţia maxima a videoclipului este setată la %1</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Clear recent searches</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Most relevant</source>
        <translation>Cele mai relevante</translation>
    </message>
    <message>
        <source>Most recent</source>
        <translation>Cele mai recente</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>Cele mai vizualizate</translation>
    </message>
    <message>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation type="obsolete">Te uiţi la %1</translation>
    </message>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Acum poţi lipi link-ul într-o altă aplicaţie</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Acum poţi lipi link-ul stream-ului într-o altă aplicaţie</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>Link-ul va fi valid doar pentru o perioadă limitată de timp.</translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>It allows you to test the application and see if it works for you.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <source>Network error: %1</source>
        <translation>Eroare de reţea : %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <source>%1 views</source>
        <translation>%1 vizualizări</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Completed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Căutare</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Bine aţi venit la &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>Enter a keyword to start watching videos.</source>
        <translation type="obsolete">Efectuaţi o căutare pentru a începe să vizionaţi videoclipuri.</translation>
    </message>
    <message>
        <source>Watch</source>
        <translation>Urmăreşte</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Căutări recente</translation>
    </message>
    <message>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>Este disponibilă o nouă versiune a %1. Te rog &lt;a href=&apos;%2&apos;&gt;să actualizezi&lt;/a&gt; aplicaţia la versiunea %3</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Faceţi-vă confortabil</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter</source>
        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>a channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsView</name>
    <message>
        <source>Preferences</source>
        <translation type="obsolete">Preferinţe</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <source>Network error: %1 for %2</source>
        <translation>Eroare reţea: %1 pentru %2</translation>
    </message>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
